# aiowrpr
Toolkit to simplify work with aiohttp module

# features
* Built-in swagger specification (provides by [aiohttp-apispec](#https://aiohttp-apispec.readthedocs.io/en/latest/));
* Marshmallow schemes for requests and responses;
* Versioning of API;
